/// <reference types="lru-cache" />
import type { CacheFs } from '../../../shared/lib/utils';
import LRUCache from 'next/dist/compiled/lru-cache';
import { PrerenderManifest } from '../../../build';
import { IncrementalCacheValue, IncrementalCacheEntry } from '../../response-cache';
export interface CacheHandlerContext {
    flushToDisk?: boolean;
    pagesDir: string;
    distDir: string;
    dev?: boolean;
    fs: CacheFs;
}
export declare class CacheHandler {
    constructor(_ctx: CacheHandlerContext);
    get(_key: string): Promise<string>;
    getMeta(_key: string): Promise<{
        mtime: number;
    }>;
    set(_key: string, _data: string): Promise<void>;
}
export declare class IncrementalCache {
    prerenderManifest: PrerenderManifest;
    cache?: LRUCache<string, IncrementalCacheEntry>;
    dev?: boolean;
    cacheHandler: CacheHandler;
    constructor({ fs, dev, distDir, pagesDir, flushToDisk, maxMemoryCacheSize, getPrerenderManifest, incrementalCacheHandlerPath, }: {
        fs: CacheFs;
        dev: boolean;
        distDir: string;
        pagesDir: string;
        flushToDisk?: boolean;
        maxMemoryCacheSize?: number;
        incrementalCacheHandlerPath?: string;
        getPrerenderManifest: () => PrerenderManifest;
    });
    private calculateRevalidate;
    get(pathname: string): Promise<IncrementalCacheEntry | null>;
    set(pathname: string, data: IncrementalCacheValue | null, revalidateSeconds?: number | false): Promise<void>;
}
